# django_jsform

This project is a thin wrapper around [jsform](https://github.com/quadrant-newmedia/jsform).

We include jsform's scripts as static files, and provide some basic "javascript responses" for use with jsform_execresponse.js.

Totally untested. We might end up writing a test suite here, or we might just test features as we use them in other projects.